summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:30:19 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:30:19 -0600
commitc71ade2e373d85acf1357494b42202293dd771d2 (patch)
tree76c8495d353757024fe915f12a1c7131403d9b5a
parentc3b1da745f458ff94caeca961a7d432fa6ae703b (diff)
downloadkdirstat-c71ade2e.tar.gz
kdirstat-c71ade2e.zip
Rename a number of old tq methods that are no longer tq specific
-rw-r--r--kdirstat/kcleanup.cpp8
-rw-r--r--kdirstat/kcleanupcollection.cpp4
-rw-r--r--kdirstat/kdirstatapp.cpp6
-rw-r--r--kdirstat/kdirstatsettings.cpp78
-rw-r--r--kdirstat/kdirstatsettings.h6
-rw-r--r--kdirstat/kdirtree.cpp34
-rw-r--r--kdirstat/kdirtree.h64
-rw-r--r--kdirstat/kdirtreeiterators.cpp48
-rw-r--r--kdirstat/kdirtreeiterators.h46
-rw-r--r--kdirstat/kdirtreeview.cpp100
-rw-r--r--kdirstat/kdirtreeview.h14
-rw-r--r--kdirstat/kfeedback.cpp12
-rw-r--r--kdirstat/kpacman.cpp8
-rw-r--r--kdirstat/kpacman.h2
-rw-r--r--kdirstat/ktreemaptile.cpp10
-rw-r--r--kdirstat/ktreemaptile.h20
-rw-r--r--kdirstat/ktreemapview.h2
17 files changed, 231 insertions, 231 deletions
diff --git a/kdirstat/kcleanup.cpp b/kdirstat/kcleanup.cpp
index fa38a46..b10e443 100644
--- a/kdirstat/kcleanup.cpp
+++ b/kdirstat/kcleanup.cpp
@@ -166,11 +166,11 @@ KCleanup::confirmation( KFileInfo * item )
if ( item->isDir() || item->isDotEntry() )
{
- msg = i18n( "%1\nin directory %2" ).tqarg( cleanTitle() ).tqarg( item->url() );
+ msg = i18n( "%1\nin directory %2" ).arg( cleanTitle() ).arg( item->url() );
}
else
{
- msg = i18n( "%1\nfor file %2" ).tqarg( cleanTitle() ).tqarg( item->url() );
+ msg = i18n( "%1\nfor file %2" ).arg( cleanTitle() ).arg( item->url() );
}
if ( KMessageBox::warningContinueCancel( 0, // parentWidget
@@ -252,7 +252,7 @@ KCleanup::executeRecursive( KFileInfo *item )
{
/**
* Recursively execute in this subdirectory, but only if it
- * really is a directory: File tqchildren might have been
+ * really is a directory: File children might have been
* reparented to the directory (normally, they reside in
* the dot entry) if there are no real subdirectories on
* this directory level.
@@ -324,7 +324,7 @@ KCleanup::expandVariables( const KFileInfo * item,
return expanded;
}
-#include <tqtextcodec.h>
+#include <textcodec.h>
void
KCleanup::runCommand ( const KFileInfo * item,
const TQString & command ) const
diff --git a/kdirstat/kcleanupcollection.cpp b/kdirstat/kcleanupcollection.cpp
index 627b979..39f0b1c 100644
--- a/kdirstat/kcleanupcollection.cpp
+++ b/kdirstat/kcleanupcollection.cpp
@@ -228,10 +228,10 @@ KCleanupCollection::addUserCleanups( int number )
if ( _nextUserCleanupNo <= 9 )
// Provide a keyboard shortcut for cleanup #0..#9
- title=i18n( "User Defined Cleanup #&%1" ).tqarg(_nextUserCleanupNo);
+ title=i18n( "User Defined Cleanup #&%1" ).arg(_nextUserCleanupNo);
else
// No keyboard shortcuts for cleanups #10.. - they would be duplicates
- title=i18n( "User Defined Cleanup #%1" ).tqarg(_nextUserCleanupNo);
+ title=i18n( "User Defined Cleanup #%1" ).arg(_nextUserCleanupNo);
_nextUserCleanupNo++;
diff --git a/kdirstat/kdirstatapp.cpp b/kdirstat/kdirstatapp.cpp
index 5a91375..3eabf75 100644
--- a/kdirstat/kdirstatapp.cpp
+++ b/kdirstat/kdirstatapp.cpp
@@ -10,7 +10,7 @@
*/
-#include <tqclipboard.h>
+#include <clipboard.h>
#include <tqpopupmenu.h>
#include <tqsplitter.h>
@@ -348,7 +348,7 @@ void KDirStatApp::readMainWinConfig()
KConfig * config = kapp->config();
config->setGroup( "General Options" );
- // tqStatus settings of the various bars and views
+ // Status settings of the various bars and views
_showToolBar->setChecked( config->readBoolEntry( "Show Toolbar", true ) );
toggleToolBar();
@@ -824,7 +824,7 @@ KDirStatApp::createTreemapView()
_activityTracker, TQT_SLOT ( trackActivity( int ) ) );
}
- _treemapView->show(); // TQSplitter needs explicit show() for new tqchildren
+ _treemapView->show(); // TQSplitter needs explicit show() for new children
updateActions();
}
diff --git a/kdirstat/kdirstatsettings.h b/kdirstat/kdirstatsettings.h
index f0a5c9e..570d840 100644
--- a/kdirstat/kdirstatsettings.h
+++ b/kdirstat/kdirstatsettings.h
@@ -396,9 +396,9 @@ namespace KDirStat
*
* This is meant as a substitute for a tabbed dialog inside the tabbed
* dialog which would be much too wide and possibly confusing. Plus, this
- * list box is supposed to take care of its own tqgeometry - the normal
+ * list box is supposed to take care of its own geometry - the normal
* dumbass list box obviously cannot do that. It just uses some random
- * tqgeometry, relying on scroll bars for everything else. But in this
+ * geometry, relying on scroll bars for everything else. But in this
* special case we want all items to be visible at all times without scroll
* bars.
*
@@ -426,7 +426,7 @@ namespace KDirStat
* without scrolling. In fact, we never want to see a scroll bar with
* this kind of list box.
**/
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
/**
* Insert an entry for a cleanup action into the list box. Uses the
diff --git a/kdirstat/kdirtree.h b/kdirstat/kdirtree.h
index b00767e..d0f0f59 100644
--- a/kdirstat/kdirtree.h
+++ b/kdirstat/kdirtree.h
@@ -51,7 +51,7 @@ namespace KDirStat
/**
- * tqStatus of a directory read job.
+ * Status of a directory read job.
**/
typedef enum
{
@@ -93,8 +93,8 @@ namespace KDirStat
* easily has 150,000+ file system objects, and at least one entry of this
* sort is required for each of them.
*
- * This class provides stubs for tqchildren management, yet those stubs all
- * are default implementations that don't really deal with tqchildren.
+ * This class provides stubs for children management, yet those stubs all
+ * are default implementations that don't really deal with children.
* Derived classes need to take care of that.
*
* @short Basic file information (like obtained by the lstat() sys call)
@@ -250,39 +250,39 @@ namespace KDirStat
/**
* Returns the total size in bytes of this subtree.
- * Derived classes that have tqchildren should overwrite this.
+ * Derived classes that have children should overwrite this.
**/
virtual KFileSize totalSize() { return size(); }
/**
* Returns the total size in blocks of this subtree.
- * Derived classes that have tqchildren should overwrite this.
+ * Derived classes that have children should overwrite this.
**/
virtual KFileSize totalBlocks() { return _blocks; }
/**
- * Returns the total number of tqchildren in this subtree, excluding this item.
- * Derived classes that have tqchildren should overwrite this.
+ * Returns the total number of children in this subtree, excluding this item.
+ * Derived classes that have children should overwrite this.
**/
virtual int totalItems() { return 0; }
/**
* Returns the total number of subdirectories in this subtree,
* excluding this item. Dot entries and "." or ".." are not counted.
- * Derived classes that have tqchildren should overwrite this.
+ * Derived classes that have children should overwrite this.
**/
virtual int totalSubDirs() { return 0; }
/**
- * Returns the total number of plain file tqchildren in this subtree,
+ * Returns the total number of plain file children in this subtree,
* excluding this item.
- * Derived classes that have tqchildren should overwrite this.
+ * Derived classes that have children should overwrite this.
**/
virtual int totalFiles() { return 0; }
/**
* Returns the latest modification time of this subtree.
- * Derived classes that have tqchildren should overwrite this.
+ * Derived classes that have children should overwrite this.
**/
virtual time_t latestMtime() { return _mtime; }
@@ -322,7 +322,7 @@ namespace KDirStat
/**
* Returns the number of pending read jobs in this subtree. When this
* number reaches zero, the entire subtree is done.
- * Derived classes that have tqchildren should overwrite this.
+ * Derived classes that have children should overwrite this.
**/
virtual int pendingReadJobs() { return 0; }
@@ -377,7 +377,7 @@ namespace KDirStat
{ NOT_USED( newFirstChild ); }
/**
- * Returns true if this entry has any tqchildren.
+ * Returns true if this entry has any children.
**/
virtual bool hasChildren() const;
@@ -396,7 +396,7 @@ namespace KDirStat
*
* Derived classes might or might not wish to overwrite this method;
* it's only advisable to do so if a derived class comes up with a
- * different method than brute-force search all tqchildren.
+ * different method than brute-force search all children.
*
* 'findDotEntries' specifies if locating "dot entries" (".../<Files>")
* is desired.
@@ -404,9 +404,9 @@ namespace KDirStat
virtual KFileInfo * locate( TQString url, bool findDotEntries = false );
/**
- * Insert a child into the tqchildren list.
+ * Insert a child into the children list.
*
- * The order of tqchildren in this list is absolutely undefined;
+ * The order of children in this list is absolutely undefined;
* don't rely on any implementation-specific order.
*
* This default implementation does nothing.
@@ -416,7 +416,7 @@ namespace KDirStat
/**
* Return the "Dot Entry" for this node if there is one (or 0
* otherwise): This is a pseudo entry that directory nodes use to store
- * non-directory tqchildren separately from directories. This way the end
+ * non-directory children separately from directories. This way the end
* user can easily tell which summary fields belong to the directory
* itself and which are the accumulated values of the entire subtree.
*
@@ -456,7 +456,7 @@ namespace KDirStat
virtual void childAdded( KFileInfo *newChild ) { NOT_USED( newChild ); }
/**
- * Remove a child from the tqchildren list.
+ * Remove a child from the children list.
*
* IMPORTANT: This MUST be called just prior to deleting an object of
* this class. Regrettably, this cannot simply be moved to the
@@ -464,7 +464,7 @@ namespace KDirStat
* (e.g., the virtual table - no more virtual methods).
*
* This default implementation does nothing.
- * Derived classes that can handle tqchildren should overwrite this.
+ * Derived classes that can handle children should overwrite this.
**/
virtual void unlinkChild( KFileInfo *deletedChild ) { NOT_USED( deletedChild ); }
@@ -580,7 +580,7 @@ namespace KDirStat
/**
* A more specialized version of @ref KFileInfo: This class can actually
- * manage tqchildren. The base class (@ref KFileInfo) has only stubs for the
+ * manage children. The base class (@ref KFileInfo) has only stubs for the
* respective methods to integrate seamlessly with the abstraction of a
* file / directory tree; this class fills those stubs with life.
*
@@ -594,7 +594,7 @@ namespace KDirStat
*
* If "asDotEntry" is set, this will be used as the parent's
* "dot entry", i.e. the pseudo directory that holds all the parent's
- * non-directory tqchildren. This is the only way to create a "dot
+ * non-directory children. This is the only way to create a "dot
* entry"!
**/
KDirInfo( KDirTree * tree,
@@ -637,7 +637,7 @@ namespace KDirStat
virtual KFileSize totalBlocks();
/**
- * Returns the total number of tqchildren in this subtree, excluding this item.
+ * Returns the total number of children in this subtree, excluding this item.
*
* Reimplemented - inherited from @ref KFileInfo.
**/
@@ -652,7 +652,7 @@ namespace KDirStat
virtual int totalSubDirs();
/**
- * Returns the total number of plain file tqchildren in this subtree,
+ * Returns the total number of plain file children in this subtree,
* excluding this item.
*
* Reimplemented - inherited from @ref KFileInfo.
@@ -723,9 +723,9 @@ namespace KDirStat
{ _firstChild = newfirstChild; }
/**
- * Insert a child into the tqchildren list.
+ * Insert a child into the children list.
*
- * The order of tqchildren in this list is absolutely undefined;
+ * The order of children in this list is absolutely undefined;
* don't rely on any implementation-specific order.
**/
virtual void insertChild( KFileInfo *newChild );
@@ -733,7 +733,7 @@ namespace KDirStat
/**
* Get the "Dot Entry" for this node if there is one (or 0 otherwise):
* This is a pseudo entry that directory nodes use to store
- * non-directory tqchildren separately from directories. This way the end
+ * non-directory children separately from directories. This way the end
* user can easily tell which summary fields belong to the directory
* itself and which are the accumulated values of the entire subtree.
**/
@@ -760,7 +760,7 @@ namespace KDirStat
virtual void childAdded( KFileInfo *newChild );
/**
- * Remove a child from the tqchildren list.
+ * Remove a child from the children list.
*
* IMPORTANT: This MUST be called just prior to deleting an object of
* this class. Regrettably, this cannot simply be moved to the
@@ -848,8 +848,8 @@ namespace KDirStat
/**
* Clean up unneeded / undesired dot entries:
- * Delete dot entries that don't have any tqchildren,
- * reparent dot entry tqchildren to the "real" (parent) directory if
+ * Delete dot entries that don't have any children,
+ * reparent dot entry children to the "real" (parent) directory if
* there are not subdirectory siblings at the level of the dot entry.
**/
void cleanupDotEntries();
@@ -862,7 +862,7 @@ namespace KDirStat
// Children management
KFileInfo * _firstChild; // pointer to the first child
- KFileInfo * _dotEntry; // pseudo entry to hold non-dir tqchildren
+ KFileInfo * _dotEntry; // pseudo entry to hold non-dir children
// Some cached values
@@ -1252,10 +1252,10 @@ namespace KDirStat
virtual void deletingChildNotify( KFileInfo *deletedChild );
/**
- * Notification that one or more tqchildren have been deleted.
+ * Notification that one or more children have been deleted.
*
* Directory read jobs are required to call this when one or more
- * tqchildren are deleted so the tree can emit the corresponding @ref
+ * children are deleted so the tree can emit the corresponding @ref
* deletingChild() signal. For multiple deletions (e.g. entire
* subtrees) this should only happen once at the end.
**/
diff --git a/kdirstat/kdirtreeview.cpp b/kdirstat/kdirtreeview.cpp
index a8f74df..a042d2d 100644
--- a/kdirstat/kdirtreeview.cpp
+++ b/kdirstat/kdirtreeview.cpp
@@ -433,7 +433,7 @@ void
KDirTreeView::slotFinished()
{
emit progressInfo( i18n( "Finished. Elapsed time: %1" )
- .tqarg( formatTime( _stopWatch.elapsed(), true ) ) );
+ .arg( formatTime( _stopWatch.elapsed(), true ) ) );
if ( _updateTimer )
{
@@ -463,7 +463,7 @@ void
KDirTreeView::slotAborted()
{
emit progressInfo( i18n( "Aborted. Elapsed time: %1" )
- .tqarg( formatTime( _stopWatch.elapsed(), true ) ) );
+ .arg( formatTime( _stopWatch.elapsed(), true ) ) );
if ( _updateTimer )
{
@@ -499,11 +499,11 @@ KDirTreeView::sendProgressInfo( const TQString & newCurrentDir )
#if VERBOSE_PROGRESS_INFO
emit progressInfo( i18n( "Elapsed time: %1 reading directory %2" )
- .tqarg( formatTime( _stopWatch.elapsed() ) )
- .tqarg( _currentDir ) );
+ .arg( formatTime( _stopWatch.elapsed() ) )
+ .arg( _currentDir ) );
#else
emit progressInfo( i18n( "Elapsed time: %1" )
- .tqarg( formatTime( _stopWatch.elapsed() ) ) );
+ .arg( formatTime( _stopWatch.elapsed() ) ) );
#endif
}
@@ -719,14 +719,14 @@ KDirTreeView::setTreeBackground( const TQColor &color )
void
KDirTreeView::ensureContrast()
{
- if ( tqcolorGroup().base() == white ||
- tqcolorGroup().base() == black )
+ if ( colorGroup().base() == white ||
+ colorGroup().base() == black )
{
- setTreeBackground( tqcolorGroup().midlight() );
+ setTreeBackground( colorGroup().midlight() );
}
else
{
- setTreeBackground( tqcolorGroup().base() );
+ setTreeBackground( colorGroup().base() );
}
}
@@ -778,19 +778,19 @@ KDirTreeView::popupContextMenu( TQListViewItem * listViewItem,
if ( orig->isSparseFile() )
{
text = i18n( "Sparse file: %1 (%2 Bytes) -- allocated: %3 (%4 Bytes)" )
- .tqarg( formatSize( orig->byteSize() ) )
- .tqarg( formatSizeLong( orig->byteSize() ) )
- .tqarg( formatSize( orig->allocatedSize() ) )
- .tqarg( formatSizeLong( orig->allocatedSize() ) );
+ .arg( formatSize( orig->byteSize() ) )
+ .arg( formatSizeLong( orig->byteSize() ) )
+ .arg( formatSize( orig->allocatedSize() ) )
+ .arg( formatSizeLong( orig->allocatedSize() ) );
}
else
{
text = i18n( "%1 (%2 Bytes) with %3 hard links => effective size: %4 (%5 Bytes)" )
- .tqarg( formatSize( orig->byteSize() ) )
- .tqarg( formatSizeLong( orig->byteSize() ) )
- .tqarg( orig->links() )
- .tqarg( formatSize( orig->size() ) )
- .tqarg( formatSizeLong( orig->size() ) );
+ .arg( formatSize( orig->byteSize() ) )
+ .arg( formatSizeLong( orig->byteSize() ) )
+ .arg( orig->links() )
+ .arg( formatSize( orig->size() ) )
+ .arg( formatSizeLong( orig->size() ) );
}
popupContextInfo( pos, text );
@@ -832,8 +832,8 @@ KDirTreeView::popupContextSizeInfo( const TQPoint & pos,
else
{
info = i18n( "%1 (%2 Bytes)" )
- .tqarg( formatSize( size ) )
- .tqarg( formatSizeLong( size ) );
+ .arg( formatSize( size ) )
+ .arg( formatSizeLong( size ) );
}
popupContextInfo( pos, info );
@@ -1021,15 +1021,15 @@ KDirTreeViewItem::init( KDirTreeView * view,
if ( _orig->isSparseFile() )
{
text = i18n( "%1 / %2 Links (allocated: %3)" )
- .tqarg( formatSize( _orig->byteSize() ) )
- .tqarg( formatSize( _orig->links() ) )
- .tqarg( formatSize( _orig->allocatedSize() ) );
+ .arg( formatSize( _orig->byteSize() ) )
+ .arg( formatSize( _orig->links() ) )
+ .arg( formatSize( _orig->allocatedSize() ) );
}
else
{
text = i18n( "%1 / %2 Links" )
- .tqarg( formatSize( _orig->byteSize() ) )
- .tqarg( _orig->links() );
+ .arg( formatSize( _orig->byteSize() ) )
+ .arg( _orig->links() );
}
}
else // No multiple links or no regular file
@@ -1037,8 +1037,8 @@ KDirTreeViewItem::init( KDirTreeView * view,
if ( _orig->isSparseFile() )
{
text = i18n( "%1 (allocated: %2)" )
- .tqarg( formatSize( _orig->byteSize() ) )
- .tqarg( formatSize( _orig->allocatedSize() ) );
+ .arg( formatSize( _orig->byteSize() ) )
+ .arg( formatSize( _orig->allocatedSize() ) );
}
else
{
@@ -1065,9 +1065,9 @@ KDirTreeViewItem::init( KDirTreeView * view,
* Determine whether or not this item can be opened.
*
* Normally, TQt handles this very well, but when lazy cloning is in
- * effect, TQt cannot know whether or not there are tqchildren - they may
+ * effect, TQt cannot know whether or not there are children - they may
* only be in the original tree until the user tries to open this
- * item. So let's assume there may be tqchildren as long as the directory
+ * item. So let's assume there may be children as long as the directory
* is still being read.
*/
@@ -1170,7 +1170,7 @@ KDirTreeViewItem::updateSummary()
TQString text = "";
if ( jobs > 0 )
- text = i18n( "[%1 Read Jobs]" ).tqarg( formatCount( _orig->pendingReadJobs(), true ) );
+ text = i18n( "[%1 Read Jobs]" ).arg( formatCount( _orig->pendingReadJobs(), true ) );
setText( _view->readJobsCol(), text );
#endif
}
@@ -1202,15 +1202,15 @@ KDirTreeViewItem::updateSummary()
if ( ! _pacMan )
_pacMan = new KPacManAnimation( _view, height()-4, true );
- tqrepaint();
+ repaint();
}
- if ( ! isOpen() ) // Lazy update: Nobody can see the tqchildren
+ if ( ! isOpen() ) // Lazy update: Nobody can see the children
return; // -> don't update them.
- // Update all tqchildren
+ // Update all children
KDirTreeViewItem *child = firstChild();
@@ -1231,7 +1231,7 @@ KDirTreeViewItem::locate( KFileInfo * wanted,
if ( lazy && ! isOpen() )
{
/*
- * In "lazy" mode, we don't bother searching all the tqchildren of this
+ * In "lazy" mode, we don't bother searching all the children of this
* item if they are not visible (i.e. the branch is open) anyway. In
* this case, cloning that branch is deferred until the branch is
* actually opened - which in most cases will never happen anyway (most
@@ -1243,7 +1243,7 @@ KDirTreeViewItem::locate( KFileInfo * wanted,
*
* Note that this mode is _independent_ of lazy cloning in general: The
* caller explicitly specifies if he wants to locate an item at all
- * cost, even if that means deferred cloning tqchildren whose creation
+ * cost, even if that means deferred cloning children whose creation
* has been delayed until now.
*/
@@ -1261,13 +1261,13 @@ KDirTreeViewItem::locate( KFileInfo * wanted,
if ( wanted->urlPart( level ) == _orig->name() )
{
- // Search all tqchildren
+ // Search all children
KDirTreeViewItem *child = firstChild();
if ( ! child && _orig->hasChildren() && doClone )
{
- // kdDebug() << "Deferred cloning " << this << " for tqchildren search of " << wanted << endl;
+ // kdDebug() << "Deferred cloning " << this << " for children search of " << wanted << endl;
deferredClone();
child = firstChild();
}
@@ -1294,14 +1294,14 @@ KDirTreeViewItem::deferredClone()
if ( ! _orig->hasChildren() )
{
- // kdDebug() << k_funcinfo << "Oops, no tqchildren - sorry for bothering you!" << endl;
+ // kdDebug() << k_funcinfo << "Oops, no children - sorry for bothering you!" << endl;
setExpandable( false );
return;
}
- // Clone all normal tqchildren
+ // Clone all normal children
int level = _orig->treeLevel();
bool startingClean = ! firstChild();
@@ -1367,7 +1367,7 @@ KDirTreeViewItem::cleanupDotEntries()
return;
- // Reparent dot entry tqchildren if there are no subdirectories on this level
+ // Reparent dot entry children if there are no subdirectories on this level
if ( ! _orig->firstChild() )
{
@@ -1391,9 +1391,9 @@ KDirTreeViewItem::cleanupDotEntries()
/*
* Immediately delete the (now emptied) dot entry. The algorithm for
* the original tree doesn't quite fit here - there, the dot entry is
- * actually deleted in the step below. But the 'no tqchildren' check for
+ * actually deleted in the step below. But the 'no children' check for
* this fails here since the original dot entry still _has_ its
- * tqchildren - they will be deleted only after all clones have been
+ * children - they will be deleted only after all clones have been
* processed.
*
* This had been the cause for a core that took me quite some time to
@@ -1404,7 +1404,7 @@ KDirTreeViewItem::cleanupDotEntries()
}
- // Delete dot entries without any tqchildren
+ // Delete dot entries without any children
if ( ! _orig->dotEntry()->firstChild() && dotEntry )
{
@@ -1593,16 +1593,16 @@ KDirTreeViewItem::compare( TQListViewItem * otherListViewItem,
void
KDirTreeViewItem::paintCell( TQPainter * painter,
- const TQColorGroup & tqcolorGroup,
+ const TQColorGroup & colorGroup,
int column,
int width,
- int tqalignment )
+ int alignment )
{
// _view->incDebugCount(5);
if ( column == _view->percentBarCol() )
{
- painter->setBackgroundColor( tqcolorGroup.base() );
+ painter->setBackgroundColor( colorGroup.base() );
if ( _percent > 0.0 )
{
@@ -1634,10 +1634,10 @@ KDirTreeViewItem::paintCell( TQPainter * painter,
&& ! _pacMan )
{
TQListViewItem::paintCell( painter,
- tqcolorGroup,
+ colorGroup,
column,
width,
- tqalignment );
+ alignment );
}
else
{
@@ -1654,10 +1654,10 @@ KDirTreeViewItem::paintCell( TQPainter * painter,
* alignments etc.
*/
TQListViewItem::paintCell( painter,
- tqcolorGroup,
+ colorGroup,
column,
width,
- tqalignment );
+ alignment );
}
}
diff --git a/kdirstat/kdirtreeview.h b/kdirstat/kdirtreeview.h
index 8c9fe8d..f33b56c 100644
--- a/kdirstat/kdirtreeview.h
+++ b/kdirstat/kdirtreeview.h
@@ -148,7 +148,7 @@ namespace KDirStat
* Set the fill color of percentage bars of the specified directory
* level (0..KDirTreeViewMaxFillColor-1).
*
- * Calling tqrepaint() after setting all desired colors is the
+ * Calling repaint() after setting all desired colors is the
* caller's responsibility.
**/
void setFillColor( int level, const TQColor &color );
@@ -172,7 +172,7 @@ namespace KDirStat
/**
* Set the tree background color.
*
- * Calling tqrepaint() after setting all desired colors is the
+ * Calling repaint() after setting all desired colors is the
* caller's responsibility.
**/
void setTreeBackground( const TQColor &color );
@@ -352,7 +352,7 @@ namespace KDirStat
* Returns the minimum recommended size for this widget.
* Reimplemented from TQWidget.
**/
- virtual TQSize tqminimumSizeHint() const { return TQSize( 0, 0 ); }
+ virtual TQSize minimumSizeHint() const { return TQSize( 0, 0 ); }
protected slots:
@@ -720,8 +720,8 @@ namespace KDirStat
void setIcon();
/**
- * Remove dot entry if it doesn't have any tqchildren.
- * Reparent all of the dot entry's tqchildren if there are no
+ * Remove dot entry if it doesn't have any children.
+ * Reparent all of the dot entry's children if there are no
* subdirectories on this level.
**/
void cleanupDotEntries();
@@ -745,10 +745,10 @@ namespace KDirStat
* Reimplemented from @ref TQListViewItem.
**/
virtual void paintCell ( TQPainter * painter,
- const TQColorGroup & tqcolorGroup,
+ const TQColorGroup & colorGroup,
int column,
int width,
- int tqalignment );
+ int alignment );
/**
* Paint a percentage bar into a @ref TQListViewItem cell.
diff --git a/kdirstat/kfeedback.cpp b/kdirstat/kfeedback.cpp
index 21e54ff..9bd80e8 100644
--- a/kdirstat/kfeedback.cpp
+++ b/kdirstat/kfeedback.cpp
@@ -10,7 +10,7 @@
#include <tqheader.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqlabel.h>
#include <tqmultilineedit.h>
#include <tqhbox.h>
@@ -34,7 +34,7 @@ KFeedbackDialog::KFeedbackDialog( const TQString & feedbackMailAddress,
| ( helpTopic.isEmpty() ? 0 : (int) Help ), // buttonMask
Apply ) // defaultButton
{
- TQVBoxLayout * tqlayout = new TQVBoxLayout( plainPage(), 0, spacingHint() );
+ TQVBoxLayout * layout = new TQVBoxLayout( plainPage(), 0, spacingHint() );
setButtonApply( KGuiItem( i18n( "&Mail this..." ) ) );
if ( ! helpTopic.isEmpty() )
@@ -43,7 +43,7 @@ KFeedbackDialog::KFeedbackDialog( const TQString & feedbackMailAddress,
_form = new KFeedbackForm( feedbackMailAddress, plainPage() );
CHECK_PTR( _form );
- tqlayout->addWidget( _form );
+ layout->addWidget( _form );
checkSendButton();
connect( this, TQT_SIGNAL( applyClicked() ),
@@ -112,16 +112,16 @@ KFeedbackForm::KFeedbackForm( const TQString & feedbackMailAddress,
label = new TQLabel( i18n( "Questions marked with " ), hbox );
CHECK_PTR( label );
- label->tqsetSizePolicy( pol );
+ label->setSizePolicy( pol );
label = new TQLabel( hbox );
CHECK_PTR( label );
label->setPixmap( KGlobal::iconLoader()->loadIcon( "edit", KIcon::Small ) );
- label->tqsetSizePolicy( pol );
+ label->setSizePolicy( pol );
label = new TQLabel( i18n( " must be answered before a mail can be sent.") , hbox );
CHECK_PTR( label );
- label->tqsetSizePolicy( pol );
+ label->setSizePolicy( pol );
new TQWidget( hbox ); // Fill any leftover space to the right.
diff --git a/kdirstat/kpacman.cpp b/kdirstat/kpacman.cpp
index 22c5176..e973e3e 100644
--- a/kdirstat/kpacman.cpp
+++ b/kdirstat/kpacman.cpp
@@ -163,7 +163,7 @@ KPacManAnimation::animate( TQPainter * painter,
// Transfer pixmap into widget
#if 0
- TQPoint offset = painter->tqworldMatrix().map( _pacManRect.topLeft() );
+ TQPoint offset = painter->worldMatrix().map( _pacManRect.topLeft() );
// kdDebug() << "bitBlt() to " << offset.x() << ", " << offset.y() << endl;
bitBlt( _widget, offset, &pixmap );
#endif
@@ -254,14 +254,14 @@ KPacMan::stop()
if ( _timer )
_timer->stop();
- tqrepaint();
+ repaint();
}
void
KPacMan::animate()
{
- tqrepaint( false );
+ repaint( false );
}
@@ -300,7 +300,7 @@ KPacMan::mouseReleaseEvent ( TQMouseEvent *ev )
TQSize
-KPacMan::tqsizeHint() const
+KPacMan::sizeHint() const
{
return TQSize( 16 * _pacManSize, // width - admittedly somewhat random
_pacManSize + 2 * _margin ); // height
diff --git a/kdirstat/kpacman.h b/kdirstat/kpacman.h
index e088cd5..7de9357 100644
--- a/kdirstat/kpacman.h
+++ b/kdirstat/kpacman.h
@@ -211,7 +211,7 @@ public:
*
* Reimplemented from @ref TQWidget.
**/
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
public slots:
diff --git a/kdirstat/ktreemaptile.h b/kdirstat/ktreemaptile.h
index 26d8f45..e36a08a 100644
--- a/kdirstat/ktreemaptile.h
+++ b/kdirstat/ktreemaptile.h
@@ -125,7 +125,7 @@ namespace KDirStat
/**
* This is the basic building block of a treemap view: One single tile of a
* treemap. If it corresponds to a leaf in the tree, it will be visible as
- * one tile (one rectangle) of the treemap. If it has tqchildren, it will be
+ * one tile (one rectangle) of the treemap. If it has children, it will be
* subdivided again.
*
* @short Basic building block of a treemap
@@ -192,13 +192,13 @@ namespace KDirStat
protected:
/**
- * Create tqchildren (sub-tiles) of this tile.
+ * Create children (sub-tiles) of this tile.
**/
void createChildren ( const TQRect & rect,
KOrientation orientation );
/**
- * Create tqchildren (sub-tiles) using the simple treemap algorithm:
+ * Create children (sub-tiles) using the simple treemap algorithm:
* Alternate between horizontal and vertical subdivision in each
* level. Each child will get the entire height or width, respectively,
* of the specified rectangle. This algorithm is very fast, but often
@@ -208,27 +208,27 @@ namespace KDirStat
KOrientation orientation );
/**
- * Create tqchildren using the "squarified treemaps" algorithm as
+ * Create children using the "squarified treemaps" algorithm as
* described by Mark Bruls, Kees Huizing, and Jarke J. van Wijk of the
* TU Eindhoven, NL.
*
* This algorithm is not quite so simple and involves more expensive
- * operations, e.g., sorting the tqchildren of each node by size first,
- * try some variations of the tqlayout and maybe backtrack to the
+ * operations, e.g., sorting the children of each node by size first,
+ * try some variations of the layout and maybe backtrack to the
* previous attempt. But it results in tiles that are much more
* square-like, i.e. have more reasonable width-to-height ratios. It is
* very much less likely to get thin, elongated tiles that are hard to
* point at and even harder to compare visually against each other.
*
* This implementation includes some improvements to that basic
- * algorithm. For example, tqchildren below a certain size are
+ * algorithm. For example, children below a certain size are
* disregarded completely since they will not get an adequate visual
* representation anyway (it would be way too small). They are
* summarized in some kind of 'misc stuff' area in the parent treemap
* tile - in fact, part of the parent directory's tile can be "seen
* through".
*
- * In short, a lot of small tqchildren that don't have any useful effect
+ * In short, a lot of small children that don't have any useful effect
* for the user in finding wasted disk space are omitted from handling
* and, most important, don't need to be sorted by size (which has a
* cost of O(n*ln(n)) in the best case, so reducing n helps a lot).
@@ -236,9 +236,9 @@ namespace KDirStat
void createSquarifiedChildren( const TQRect & rect );
/**
- * Squarify as many tqchildren as possible: Try to squeeze members
+ * Squarify as many children as possible: Try to squeeze members
* referred to by 'it' into 'rect' until the aspect ratio doesn't get
- * better any more. Returns a list of tqchildren that should be laid out
+ * better any more. Returns a list of children that should be laid out
* in 'rect'. Moves 'it' until there is no more improvement or 'it'
* runs out of items.
*
diff --git a/kdirstat/ktreemapview.h b/kdirstat/ktreemapview.h
index 29b43c9..119a5b8 100644
--- a/kdirstat/ktreemapview.h
+++ b/kdirstat/ktreemapview.h
@@ -69,7 +69,7 @@ namespace KDirStat
* Returns the minimum recommended size for this widget.
* Reimplemented from TQWidget.
**/
- virtual TQSize tqminimumSizeHint() const { return TQSize( 0, 0 ); }
+ virtual TQSize minimumSizeHint() const { return TQSize( 0, 0 ); }
/**
* Returns this treemap view's currently selected treemap tile or 0 if
diff --git a/kdirstat/kdirstatsettings.cpp b/kdirstat/kdirstatsettings.cpp
index e33a515..b3d036f 100644
--- a/kdirstat/kdirstatsettings.cpp
+++ b/kdirstat/kdirstatsettings.cpp
@@ -12,7 +12,7 @@
#include <tqcheckbox.h>
#include <tqcombobox.h>
#include <tqlabel.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqlineedit.h>
#include <tqslider.h>
#include <tqvbox.h>
@@ -44,21 +44,21 @@ KSettingsDialog::KSettingsDialog( KDirStatApp *mainWin )
{
/**
* This may seem like overkill, but I didn't find any other way to get
- * tqgeometry management right with KDialogBase, yet maintain a modular and
+ * geometry management right with KDialogBase, yet maintain a modular and
* object-oriented design:
*
* Each individual settings page is added with 'addVBoxPage()' to get some
- * initial tqgeometry management. Only then can some generic widget be added
+ * initial geometry management. Only then can some generic widget be added
* into this - and I WANT my settings pages to be generic widgets. I want
* them to be self-sufficient - no monolithic mess of widget creation in my
- * code, intermixed with all kinds of tqlayout objects.
+ * code, intermixed with all kinds of layout objects.
*
* The ordinary KDialogBase::addPage() just creates a TQFrame which is too
- * dumb for any kind of tqgeometry management - it cannot even handle one
+ * dumb for any kind of geometry management - it cannot even handle one
* single child right. So, let's have KDialogBase create something more
* intelligent: A TQVBox (which is derived from TQFrame anyway). This TQVBox
* gets only one child - the KSettingsPage. This KSettingsPage handles its
- * own tqlayout.
+ * own layout.
**/
TQWidget * page;
@@ -79,7 +79,7 @@ KSettingsDialog::KSettingsDialog( KDirStatApp *mainWin )
_generalSettingsPageIndex = pageIndex( page );
new KGeneralSettingsPage( this, page, _mainWin );
- // resize( tqsizeHint() );
+ // resize( sizeHint() );
}
@@ -166,14 +166,14 @@ KTreeColorsPage::KTreeColorsPage( KSettingsDialog * dialog,
, _treeView( mainWin->treeView() )
, _maxButtons( KDirStatSettingsMaxColorButton )
{
- // Outer tqlayout box
+ // Outer layout box
TQHBoxLayout * outerBox = new TQHBoxLayout( this,
0, // border
dialog->spacingHint() );
- // Inner tqlayout box with a column of color buttons
+ // Inner layout box with a column of color buttons
TQGridLayout *grid = new TQGridLayout( _maxButtons, // rows
_maxButtons + 1, // cols
@@ -190,7 +190,7 @@ KTreeColorsPage::KTreeColorsPage( KSettingsDialog * dialog,
{
TQString labelText;
- labelText=i18n( "Tree Level %1" ).tqarg(i+1);
+ labelText=i18n( "Tree Level %1" ).arg(i+1);
_colorLabel[i] = new TQLabel( labelText, this );
grid->addWidget( _colorLabel [i], i, 0 );
@@ -284,9 +284,9 @@ KCleanupPage::KCleanupPage( KSettingsDialog * dialog,
_workCleanupCollection = *mainWin->cleanupCollection();
- // Create tqlayout and widgets.
+ // Create layout and widgets.
- TQHBoxLayout * tqlayout = new TQHBoxLayout( this,
+ TQHBoxLayout * layout = new TQHBoxLayout( this,
0, // border
dialog->spacingHint() ); // spacing
_listBox = new KCleanupListBox( this );
@@ -302,17 +302,17 @@ KCleanupPage::KCleanupPage( KSettingsDialog * dialog,
this, TQT_SLOT ( changeCleanup( KCleanup * ) ) );
- // Fill list box so it can determine a reasonable startup tqgeometry - that
+ // Fill list box so it can determine a reasonable startup geometry - that
// doesn't work if it happens only later.
setup();
// Now that _listBox will (hopefully) have determined a reasonable
- // default tqgeometry, add the widgets to the tqlayout.
+ // default geometry, add the widgets to the layout.
- tqlayout->addWidget( _listBox, 0 );
- tqlayout->addWidget( _props , 1 );
- tqlayout->activate();
+ layout->addWidget( _listBox, 0 );
+ layout->addWidget( _props , 1 );
+ layout->activate();
}
@@ -370,7 +370,7 @@ KCleanupPage::setup()
// (Re-) Initialize list box.
- // _listBox->resize( _listBox->tqsizeHint() );
+ // _listBox->resize( _listBox->sizeHint() );
_listBox->setSelected( 0, true );
}
@@ -437,13 +437,13 @@ KCleanupListBox::KCleanupListBox( TQWidget *parent )
TQSize
-KCleanupListBox::tqsizeHint() const
+KCleanupListBox::sizeHint() const
{
// FIXME: Is this still needed with TQt 2.x?
if ( count() < 1 )
{
// As long as the list is empty, tqsizeHint() would default to
// (0,0) which is ALWAYS just a pain in the ass. We'd rather
// have an absolutely random value than this.
return TQSize( 100, 100 );
@@ -544,7 +544,7 @@ KCleanupPropertiesPage::KCleanupPropertiesPage( TQWidget * parent,
TQVBoxLayout *fieldsBox = new TQVBoxLayout( _fields );
- // Grid tqlayout for the edit fields, their labels, some
+ // Grid layout for the edit fields, their labels, some
// explanatory text and the "recurse?" check box.
TQGridLayout *grid = new TQGridLayout( 7, // rows
@@ -611,7 +611,7 @@ KCleanupPropertiesPage::KCleanupPropertiesPage( TQWidget * parent,
_worksForProtocols->insertItem( i18n( "Network Transparent (ftp, smb, tar, ...)" ) );
- // Grid tqlayout for combo boxes at the bottom
+ // Grid layout for combo boxes at the bottom
grid = new TQGridLayout( 1, // rows
2, // cols
@@ -646,7 +646,7 @@ KCleanupPropertiesPage::KCleanupPropertiesPage( TQWidget * parent,
outerBox->activate();
- setMinimumSize( tqsizeHint() );
+ setMinimumSize( sizeHint() );
}
@@ -707,13 +707,13 @@ KGeneralSettingsPage::KGeneralSettingsPage( KSettingsDialog * dialog,
, _treeView( mainWin->treeView() )
{
- // Create tqlayout and widgets.
+ // Create layout and widgets.
- TQVBoxLayout * tqlayout = new TQVBoxLayout( this, 5, // border
+ TQVBoxLayout * layout = new TQVBoxLayout( this, 5, // border
dialog->spacingHint() ); // spacing
TQVGroupBox * gbox = new TQVGroupBox( i18n( "Directory Reading" ), this );
- tqlayout->addWidget( gbox );
+ layout->addWidget( gbox );
_crossFileSystems = new TQCheckBox( i18n( "Cross &File System Boundaries" ), gbox );
_enableLocalDirReader = new TQCheckBox( i18n( "Use Optimized &Local Directory Read Methods" ), gbox );
@@ -721,10 +721,10 @@ KGeneralSettingsPage::KGeneralSettingsPage( KSettingsDialog * dialog,
connect( _enableLocalDirReader, TQT_SIGNAL( stateChanged( int ) ),
this, TQT_SLOT ( checkEnabledState() ) );
- tqlayout->addSpacing( 10 );
+ layout->addSpacing( 10 );
gbox = new TQVGroupBox( i18n( "Animation" ), this );
- tqlayout->addWidget( gbox );
+ layout->addWidget( gbox );
_enableToolBarAnimation = new TQCheckBox( i18n( "P@cM@n Animation in Tool &Bar" ), gbox );
_enableTreeViewAnimation = new TQCheckBox( i18n( "P@cM@n Animation in Directory &Tree" ), gbox );
@@ -800,11 +800,11 @@ KTreemapPage::KTreemapPage( KSettingsDialog * dialog,
{
// kdDebug() << k_funcinfo << endl;
- TQVBoxLayout * tqlayout = new TQVBoxLayout( this, 0, 0 ); // parent, border, spacing
+ TQVBoxLayout * layout = new TQVBoxLayout( this, 0, 0 ); // parent, border, spacing
TQVBox * vbox = new TQVBox( this );
vbox->setSpacing( dialog->spacingHint() );
- tqlayout->addWidget( vbox );
+ layout->addWidget( vbox );
_squarify = new TQCheckBox( i18n( "S&quarify Treemap" ), vbox );
_doCushionShading = new TQCheckBox( i18n( "Use C&ushion Shading" ), vbox );
@@ -815,7 +815,7 @@ KTreemapPage::KTreemapPage( KSettingsDialog * dialog,
TQVGroupBox * gbox = new TQVGroupBox( i18n( "Cushion Parameters" ), vbox );
_cushionParams = gbox;
gbox->addSpace( 7 );
- gbox->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding ) );
+ gbox->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding ) );
TQLabel * label = new TQLabel( i18n( "Ambient &Light" ), gbox );
TQHBox * hbox = new TQHBox( gbox );
@@ -823,7 +823,7 @@ KTreemapPage::KTreemapPage( KSettingsDialog * dialog,
DefaultAmbientLight,Qt::Horizontal, hbox );
_ambientLightSB = new TQSpinBox( MinAmbientLight, MaxAmbientLight, 1, // min, max, step
hbox );
- _ambientLightSB->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum ) );
+ _ambientLightSB->setSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum ) );
label->setBuddy( _ambientLightSB );
gbox->addSpace( 7 );
@@ -833,7 +833,7 @@ KTreemapPage::KTreemapPage( KSettingsDialog * dialog,
DefaultHeightScalePercent,Qt::Horizontal, hbox );
_heightScalePercentSB = new TQSpinBox( MinHeightScalePercent, MaxHeightScalePercent, 1, // min, max, step
hbox );
- _heightScalePercentSB->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum ) );
+ _heightScalePercentSB->setSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum ) );
label->setBuddy( _heightScalePercentSB );
gbox->addSpace( 10 );
@@ -847,7 +847,7 @@ KTreemapPage::KTreemapPage( KSettingsDialog * dialog,
_cushionGridColorL = new TQLabel( " " + i18n( "Gr&id Color: " ), hbox );
_cushionGridColor = new KColorButton( hbox );
_cushionGridColorL->setBuddy( _cushionGridColor );
- _cushionGridColorL->tqsetAlignment( AlignRight | AlignVCenter );
+ _cushionGridColorL->setAlignment( AlignRight | AlignVCenter );
// addVStretch( vbox );
@@ -860,17 +860,17 @@ KTreemapPage::KTreemapPage( KSettingsDialog * dialog,
label = new TQLabel( i18n( "&Files: " ), _plainTileParams );
_fileFillColor = new KColorButton( _plainTileParams );
label->setBuddy( _fileFillColor );
- label->tqsetAlignment( AlignRight | AlignVCenter );
+ label->setAlignment( AlignRight | AlignVCenter );
label = new TQLabel( " " + i18n( "&Directories: " ), _plainTileParams );
_dirFillColor = new KColorButton( _plainTileParams );
label->setBuddy( _dirFillColor );
- label->tqsetAlignment( AlignRight | AlignVCenter );
+ label->setAlignment( AlignRight | AlignVCenter );
label = new TQLabel( i18n( "Gr&id: " ), _plainTileParams );
_outlineColor = new KColorButton( _plainTileParams );
label->setBuddy( _outlineColor );
- label->tqsetAlignment( AlignRight | AlignVCenter );
+ label->setAlignment( AlignRight | AlignVCenter );
// Misc
@@ -1035,7 +1035,7 @@ void
addHStretch( TQWidget * parent )
{
TQWidget * stretch = new TQWidget( parent );
- stretch->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, // hor
+ stretch->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, // hor
TQSizePolicy::Minimum, // vert
1, // hstretch
0 ) ); // vstretch
@@ -1046,7 +1046,7 @@ void
addVStretch( TQWidget * parent )
{
TQWidget * stretch = new TQWidget( parent );
- stretch->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, // hor
+ stretch->setSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, // hor
TQSizePolicy::Expanding, // vert
0, // hstretch
1 ) ); // vstretch
@@ -437,13 +437,13 @@ KCleanupListBox::KCleanupListBox( TQWidget *parent )
if ( count() < 1 )
{
- // As long as the list is empty, tqsizeHint() would default to
+ // As long as the list is empty, sizeHint() would default to
// (0,0) which is ALWAYS just a pain in the ass. We'd rather
// have an absolutely random value than this.
diff --git a/kdirstat/kdirtree.cpp b/kdirstat/kdirtree.cpp
index 34da482..e80e916 100644
--- a/kdirstat/kdirtree.cpp
+++ b/kdirstat/kdirtree.cpp
@@ -151,7 +151,7 @@ KFileInfo::~KFileInfo()
/**
* The destructor should also take care about unlinking this object from
* its parent's tqchildren list, but regrettably that just doesn't work: At
* this point (within the destructor) parts of the object are already
* destroyed, e.g., the virtual table - virtual methods don't work any
* more. Thus, somebody from outside must call deletingChild() just prior
@@ -296,11 +296,11 @@ KFileInfo::locate( TQString url, bool findDotEntries )
{
if ( _name.right(1) != "/" && // and this is not the root directory
! isDotEntry() ) // or a dot entry:
- return 0; // This can't be any of our tqchildren.
+ return 0; // This can't be any of our children.
}
// Search all tqchildren
KFileInfo *child = firstChild();
@@ -323,8 +323,8 @@ KFileInfo::locate( TQString url, bool findDotEntries )
// Search the dot entry if there is one - but only if there is no more
// path delimiter left in the URL. The dot entry contains files only,
// and their names may not contain the path delimiter, nor can they
// have tqchildren. This check is not strictly necessary, but it may
// speed up things a bit if we don't search the non-directory tqchildren
// if the rest of the URL consists of several pathname components.
if ( dotEntry() &&
@@ -415,7 +415,7 @@ KDirInfo::~KDirInfo()
KFileInfo *child = _firstChild;
// Recursively delete all tqchildren.
while ( child )
{
@@ -585,7 +585,7 @@ KDirInfo::insertChild( KFileInfo *newChild )
* unless something went terribly wrong, e.g. there is no dot entry to use.
* If this is a dot entry, store everything it gets directly within it.
*
* In any of those cases, insert the new child in the tqchildren list.
*
* We don't bother with this list's order - it's explicitly declared to
* be unordered, so be warned! We simply insert this new child at the
@@ -652,7 +652,7 @@ void
KDirInfo::deletingChild( KFileInfo *deletedChild )
{
/**
* When tqchildren are deleted, things go downhill: Marking the summary
* fields as dirty (i.e. outdated) is the only thing that can be done here.
*
* The accumulated sizes could be updated (by subtracting this deleted
@@ -672,9 +672,9 @@ KDirInfo::deletingChild( KFileInfo *deletedChild )
if ( ! _beingDestroyed && deletedChild->parent() == this )
{
/**
* Unlink the child from the tqchildren's list - but only if this doesn't
* happen recursively in the destructor of this object: No use
* bothering about the validity of the tqchildren's list if this will all
* be history anyway in a moment.
**/
@@ -689,7 +689,7 @@ KDirInfo::unlinkChild( KFileInfo *deletedChild )
if ( deletedChild->parent() != this )
{
kdError() << deletedChild << " is not a child of " << this
- << " - cannot unlink from tqchildren list!" << endl;
+ << " - cannot unlink from children list!" << endl;
return;
}
@@ -716,7 +716,7 @@ KDirInfo::unlinkChild( KFileInfo *deletedChild )
}
kdError() << "Couldn't unlink " << deletedChild << " from "
- << this << " tqchildren list" << endl;
+ << this << " children list" << endl;
}
@@ -773,14 +773,14 @@ KDirInfo::cleanupDotEntries()
if ( ! _dotEntry || _isDotEntry )
return;
// Reparent dot entry tqchildren if there are no subdirectories on this level
if ( ! _firstChild )
{
// kdDebug() << "Removing solo dot entry " << this << " " << endl;
KFileInfo *child = _dotEntry->firstChild();
- _firstChild = child; // Move the entire tqchildren chain here.
+ _firstChild = child; // Move the entire children chain here.
_dotEntry->setFirstChild( 0 ); // _dotEntry will be deleted below.
while ( child )
@@ -791,7 +791,7 @@ KDirInfo::cleanupDotEntries()
}
// Delete dot entries without any tqchildren
if ( ! _dotEntry->firstChild() )
{
@@ -1301,7 +1301,7 @@ KDirTree::refresh( KFileInfo *subtree )
/**
* This may sound stupid, but the parent must be told to unlink its
* child from the tqchildren list. The child cannot simply do this by
* itself in its destructor since at this point important parts of the
* object may already be destroyed, e.g., the virtual table -
* i.e. virtual methods won't work any more.
@@ -1449,7 +1449,7 @@ KDirTree::deleteSubtree( KFileInfo *subtree )
if ( parent )
{
// Give the parent of the child to be deleted a chance to unlink the
// child from its tqchildren list and take care of internal summary
// fields
parent->deletingChild( subtree );
}
@@ -151,7 +151,7 @@ KFileInfo::~KFileInfo()
/**
* The destructor should also take care about unlinking this object from
- * its parent's tqchildren list, but regrettably that just doesn't work: At
+ * its parent's children list, but regrettably that just doesn't work: At
* this point (within the destructor) parts of the object are already
* destroyed, e.g., the virtual table - virtual methods don't work any
@@ -296,11 +296,11 @@ KFileInfo::locate( TQString url, bool findDotEntries )
}
- // Search all tqchildren
+ // Search all children
KFileInfo *child = firstChild();
@@ -323,8 +323,8 @@ KFileInfo::locate( TQString url, bool findDotEntries )
// path delimiter left in the URL. The dot entry contains files only,
// and their names may not contain the path delimiter, nor can they
- // have tqchildren. This check is not strictly necessary, but it may
- // speed up things a bit if we don't search the non-directory tqchildren
+ // have children. This check is not strictly necessary, but it may
+ // speed up things a bit if we don't search the non-directory children
// if the rest of the URL consists of several pathname components.
if ( dotEntry() &&
@@ -415,7 +415,7 @@ KDirInfo::~KDirInfo()
KFileInfo *child = _firstChild;
- // Recursively delete all tqchildren.
+ // Recursively delete all children.
while ( child )
{
@@ -585,7 +585,7 @@ KDirInfo::insertChild( KFileInfo *newChild )
* If this is a dot entry, store everything it gets directly within it.
*
- * In any of those cases, insert the new child in the tqchildren list.
+ * In any of those cases, insert the new child in the children list.
*
* We don't bother with this list's order - it's explicitly declared to
@@ -652,7 +652,7 @@ void
{
/**
- * When tqchildren are deleted, things go downhill: Marking the summary
+ * When children are deleted, things go downhill: Marking the summary
* fields as dirty (i.e. outdated) is the only thing that can be done here.
*
@@ -672,9 +672,9 @@ KDirInfo::deletingChild( KFileInfo *deletedChild )
{
/**
- * Unlink the child from the tqchildren's list - but only if this doesn't
+ * Unlink the child from the children's list - but only if this doesn't
* happen recursively in the destructor of this object: No use
@@ -672,9 +672,9 @@ KDirInfo::deletingChild( KFileInfo *deletedChild )
* happen recursively in the destructor of this object: No use
- * bothering about the validity of the tqchildren's list if this will all
+ * bothering about the validity of the children's list if this will all
* be history anyway in a moment.
**/
@@ -773,14 +773,14 @@ KDirInfo::cleanupDotEntries()
if ( ! _dotEntry || _isDotEntry )
return;
- // Reparent dot entry tqchildren if there are no subdirectories on this level
+ // Reparent dot entry children if there are no subdirectories on this level
if ( ! _firstChild )
{
@@ -791,7 +791,7 @@ KDirInfo::cleanupDotEntries()
}
- // Delete dot entries without any tqchildren
+ // Delete dot entries without any children
if ( ! _dotEntry->firstChild() )
{
@@ -1301,7 +1301,7 @@ KDirTree::refresh( KFileInfo *subtree )
/**
* This may sound stupid, but the parent must be told to unlink its
- * child from the tqchildren list. The child cannot simply do this by
+ * child from the children list. The child cannot simply do this by
* itself in its destructor since at this point important parts of the
* object may already be destroyed, e.g., the virtual table -
@@ -1449,7 +1449,7 @@ KDirTree::deleteSubtree( KFileInfo *subtree )
{
// Give the parent of the child to be deleted a chance to unlink the
- // child from its tqchildren list and take care of internal summary
+ // child from its children list and take care of internal summary
// fields
parent->deletingChild( subtree );
diff --git a/kdirstat/kdirtreeiterators.cpp b/kdirstat/kdirtreeiterators.cpp
index 4508e8f..aac4a90 100644
--- a/kdirstat/kdirtreeiterators.cpp
+++ b/kdirstat/kdirtreeiterators.cpp
@@ -60,7 +60,7 @@ void KFileInfoIterator::next()
{
if ( ! _directChildrenProcessed )
{
// Process direct tqchildren
_current = _current ? _current->next() : _parent->firstChild();
@@ -98,7 +98,7 @@ void KFileInfoIterator::next()
{
if ( _policy == KDotEntryTransparent )
{
// Process dot entry tqchildren
_current = _current ?
_current->next() :
@@ -129,7 +129,7 @@ KFileInfoIterator::count()
{
int cnt = 0;
// Count direct tqchildren
KFileInfo *child = _parent->firstChild();
@@ -144,7 +144,7 @@ KFileInfoIterator::count()
switch ( _policy )
{
- case KDotEntryTransparent: // Count the dot entry's tqchildren as well.
+ case KDotEntryTransparent: // Count the dot entry's children as well.
if ( _parent->dotEntry() )
{
child = _parent->dotEntry()->firstChild();
@@ -183,7 +183,7 @@ KFileInfoSortedIterator::KFileInfoSortedIterator( KFileInfo * parent,
_sortOrder = sortOrder;
_ascending = ascending;
_initComplete = false;
- _tqchildrenList = 0;
+ _childrenList = 0;
_current = 0;
}
@@ -191,8 +191,8 @@ KFileInfoSortedIterator::KFileInfoSortedIterator( KFileInfo * parent,
void
KFileInfoSortedIterator::delayedInit()
{
- _tqchildrenList = new KFileInfoList( _sortOrder, _ascending );
- CHECK_PTR( _tqchildrenList );
+ _childrenList = new KFileInfoList( _sortOrder, _ascending );
+ CHECK_PTR( _childrenList );
if ( _sortOrder == KSortByName )
{
@@ -203,45 +203,45 @@ KFileInfoSortedIterator::delayedInit()
makeChildrenList();
}
- _current = _tqchildrenList->first();
+ _current = _childrenList->first();
_initComplete = true;
}
KFileInfoSortedIterator::~KFileInfoSortedIterator()
{
- if ( _tqchildrenList )
- delete _tqchildrenList;
+ if ( _childrenList )
+ delete _childrenList;
}
void KFileInfoSortedIterator::makeDefaultOrderChildrenList()
{
// Fill tqchildren list with direct tqchildren
KFileInfo *child = _parent->firstChild();
while ( child )
{
- _tqchildrenList->append( child );
+ _childrenList->append( child );
child = child->next();
}
- _tqchildrenList->sort();
+ _childrenList->sort();
if ( _policy == KDotEntryAsSubDir && _parent->dotEntry() )
{
- // Append dot entry to the tqchildren list
+ // Append dot entry to the children list
- _tqchildrenList->append( _parent->dotEntry() );
+ _childrenList->append( _parent->dotEntry() );
}
// Append the dot entry's tqchildren to the tqchildren list
if ( _policy == KDotEntryTransparent && _parent->dotEntry() )
{
// Create a temporary list for the dot entry tqchildren
KFileInfoList dotEntryChildrenList( _sortOrder, _ascending );
child = _parent->dotEntry()->firstChild();
@@ -255,13 +255,13 @@ void KFileInfoSortedIterator::makeDefaultOrderChildrenList()
dotEntryChildrenList.sort();
// Now append all of this dot entry tqchildren list to the tqchildren list
child = dotEntryChildrenList.first();
while ( child )
{
- _tqchildrenList->append( child );
+ _childrenList->append( child );
child = dotEntryChildrenList.next();
}
}
@@ -275,11 +275,11 @@ KFileInfoSortedIterator::makeChildrenList()
while ( *it )
{
- _tqchildrenList->append( *it );
+ _childrenList->append( *it );
++it;
}
- _tqchildrenList->sort();
+ _childrenList->sort();
}
@@ -298,7 +298,7 @@ void KFileInfoSortedIterator::next()
if ( ! _initComplete )
delayedInit();
- _current = _tqchildrenList->next();
+ _current = _childrenList->next();
}
@@ -334,12 +334,12 @@ KFileInfoSortedBySizeIterator::makeChildrenList()
while ( *it )
{
if ( (*it)->totalSize() >= _minSize )
- _tqchildrenList->append( *it );
+ _childrenList->append( *it );
++it;
}
- _tqchildrenList->sort();
+ _childrenList->sort();
}
@@ -60,7 +60,7 @@ void KFileInfoIterator::next()
if ( ! _directChildrenProcessed )
{
- // Process direct tqchildren
+ // Process direct children
_current = _current ? _current->next() : _parent->firstChild();
@@ -98,7 +98,7 @@ void KFileInfoIterator::next()
if ( _policy == KDotEntryTransparent )
{
- // Process dot entry tqchildren
+ // Process dot entry children
_current = _current ?
_current->next() :
@@ -129,7 +129,7 @@ KFileInfoIterator::count()
{
int cnt = 0;
- // Count direct tqchildren
+ // Count direct children
KFileInfo *child = _parent->firstChild();
@@ -203,45 +203,45 @@ KFileInfoSortedIterator::delayedInit()
void KFileInfoSortedIterator::makeDefaultOrderChildrenList()
{
- // Fill tqchildren list with direct tqchildren
+ // Fill children list with direct children
KFileInfo *child = _parent->firstChild();
while ( child )
@@ -203,45 +203,45 @@ KFileInfoSortedIterator::delayedInit()
}
- // Append the dot entry's tqchildren to the tqchildren list
+ // Append the dot entry's children to the children list
if ( _policy == KDotEntryTransparent && _parent->dotEntry() )
{
@@ -203,45 +203,45 @@ KFileInfoSortedIterator::delayedInit()
if ( _policy == KDotEntryTransparent && _parent->dotEntry() )
{
- // Create a temporary list for the dot entry tqchildren
+ // Create a temporary list for the dot entry children
KFileInfoList dotEntryChildrenList( _sortOrder, _ascending );
child = _parent->dotEntry()->firstChild();
@@ -255,13 +255,13 @@ void KFileInfoSortedIterator::makeDefaultOrderChildrenList()
dotEntryChildrenList.sort();
- // Now append all of this dot entry tqchildren list to the tqchildren list
+ // Now append all of this dot entry children list to the children list
child = dotEntryChildrenList.first();
while ( child )
diff --git a/kdirstat/kdirtreeiterators.h b/kdirstat/kdirtreeiterators.h
index 2ab3382..f7a3ae8 100644
--- a/kdirstat/kdirtreeiterators.h
+++ b/kdirstat/kdirtreeiterators.h
@@ -27,9 +27,9 @@ namespace KDirStat
**/
typedef enum
{
- KDotEntryTransparent, // Flatten hierarchy - move dot entry tqchildren up
+ KDotEntryTransparent, // Flatten hierarchy - move dot entry children up
KDotEntryAsSubDir, // Treat dot entry as ordinary subdirectory
- KDotEntryIgnore // Ignore dot entry and its tqchildren completely
+ KDotEntryIgnore // Ignore dot entry and its children completely
} KDotEntryPolicy;
@@ -47,8 +47,8 @@ namespace KDirStat
/**
* Iterator class for tqchildren of a @ref KFileInfo object. For optimum
* performance, this iterator class does NOT return tqchildren in any
* specific sort order. If you need that, use @ref KFileInfoSortedIterator
* instead.
*
@@ -66,37 +66,37 @@ namespace KDirStat
* subdirectory child and each (direct) file child of 'node'.
* Notice: This does not recurse into subdirectories!
*
* @short (unsorted) iterator for @ref KFileInfo tqchildren.
**/
class KFileInfoIterator
{
public:
/**
* Constructor: Initialize an iterator object to iterate over the
* tqchildren of 'parent' (unsorted!), depending on 'dotEntryPolicy':
*
* KDotEntryTransparent (default):
*
* Treat the dot entry as if it wasn't there - pretend to move all its
* tqchildren up to the real parent. This makes a directory look very
* much like the directory on disk, without the dot entry. 'current()'
* or 'operator*()' will never return the dot entry, but all of its
* tqchildren. Subdirectories will be processed before any file tqchildren.
*
* KDotEntryIsSubDir:
*
* Treat the dot entry just like any other subdirectory. Don't iterate
* over its tqchildren, too (unlike KDotEntryTransparent above).
* 'current()' or 'operator*()' will return the dot entry, but none of
* its tqchildren (unless, of course, you create an iterator with the dot
* entry as the parent).
*
* KDotEntryIgnore:
*
* Ignore the dot entry and its tqchildren completely. Useful if tqchildren
* other than subdirectories are not interesting anyway. 'current()'
* or 'operator*()' will never return the dot entry nor any of its
- * tqchildren.
+ * children.
*
**/
KFileInfoIterator( KFileInfo * parent,
@@ -187,13 +187,13 @@ namespace KDirStat
/**
* Iterator class for tqchildren of a @ref KFileInfo object. This iterator
* returns tqchildren sorted by name: Subdirectories first, then the dot
* entry (if desired - depending on policy), then file tqchildren (if
* desired). Note: If you don't need the sorting feature, you might want to
* use @ref KFileItemIterator instead which has better performance.
*
* @short sorted iterator for @ref KFileInfo tqchildren.
**/
class KFileInfoSortedIterator: public KFileInfoIterator
{
@@ -248,15 +248,15 @@ namespace KDirStat
void delayedInit();
/**
* Make a 'default order' tqchildren list:
* First all subdirectories sorted by name,
* then the dot entry (depending on policy),
* then the dot entry's tqchildren (depending on policy).
**/
virtual void makeDefaultOrderChildrenList();
/**
* Make a sorted tqchildren list according to the current sort
* criteria - unless KSortByName is requested, in which case
* makeDefaultOrderChildrenList() above is used.
**/
@@ -265,7 +265,7 @@ namespace KDirStat
// Data members
- KFileInfoList * _tqchildrenList;
+ KFileInfoList * _childrenList;
KFileInfoSortOrder _sortOrder;
bool _ascending;
bool _initComplete;
@@ -276,8 +276,8 @@ namespace KDirStat
/**
* Specialized KFileInfo iterator that sorts by (total) size, yet
* disregards tqchildren below a minimum size. This can considerably improve
* performance if the number of tqchildren that need to be sorted decreases
* dramatically.
*
* For example, treemaps can only display a limited portion of large
@@ -307,7 +307,7 @@ namespace KDirStat
protected:
/**
* Create the (sorted) tqchildren list. Disregard tqchildren below minSize.
* Reimplemented from KFileInfoSortedIterator.
**/
virtual void makeChildrenList();
@@ -47,8 +47,8 @@ namespace KDirStat
/**
- * Iterator class for tqchildren of a @ref KFileInfo object. For optimum
- * performance, this iterator class does NOT return tqchildren in any
+ * Iterator class for children of a @ref KFileInfo object. For optimum
+ * performance, this iterator class does NOT return children in any
* specific sort order. If you need that, use @ref KFileInfoSortedIterator
* instead.
@@ -66,37 +66,37 @@ namespace KDirStat
* Notice: This does not recurse into subdirectories!
*
- * @short (unsorted) iterator for @ref KFileInfo tqchildren.
+ * @short (unsorted) iterator for @ref KFileInfo children.
**/
class KFileInfoIterator
@@ -66,37 +66,37 @@ namespace KDirStat
/**
* Constructor: Initialize an iterator object to iterate over the
- * tqchildren of 'parent' (unsorted!), depending on 'dotEntryPolicy':
+ * children of 'parent' (unsorted!), depending on 'dotEntryPolicy':
*
* KDotEntryTransparent (default):
@@ -66,37 +66,37 @@ namespace KDirStat
*
* Treat the dot entry as if it wasn't there - pretend to move all its
- * tqchildren up to the real parent. This makes a directory look very
+ * children up to the real parent. This makes a directory look very
* much like the directory on disk, without the dot entry. 'current()'
* or 'operator*()' will never return the dot entry, but all of its
@@ -66,37 +66,37 @@ namespace KDirStat
* much like the directory on disk, without the dot entry. 'current()'
* or 'operator*()' will never return the dot entry, but all of its
- * tqchildren. Subdirectories will be processed before any file tqchildren.
+ * children. Subdirectories will be processed before any file children.
*
* KDotEntryIsSubDir:
@@ -66,37 +66,37 @@ namespace KDirStat
*
* Treat the dot entry just like any other subdirectory. Don't iterate
- * over its tqchildren, too (unlike KDotEntryTransparent above).
+ * over its children, too (unlike KDotEntryTransparent above).
* 'current()' or 'operator*()' will return the dot entry, but none of
@@ -66,37 +66,37 @@ namespace KDirStat
* 'current()' or 'operator*()' will return the dot entry, but none of
- * its tqchildren (unless, of course, you create an iterator with the dot
+ * its children (unless, of course, you create an iterator with the dot
* entry as the parent).
*
@@ -66,37 +66,37 @@ namespace KDirStat
* KDotEntryIgnore:
*
- * Ignore the dot entry and its tqchildren completely. Useful if tqchildren
+ * Ignore the dot entry and its children completely. Useful if children
* other than subdirectories are not interesting anyway. 'current()'
* or 'operator*()' will never return the dot entry nor any of its
@@ -187,13 +187,13 @@ namespace KDirStat
/**
- * Iterator class for tqchildren of a @ref KFileInfo object. This iterator
- * returns tqchildren sorted by name: Subdirectories first, then the dot
- * entry (if desired - depending on policy), then file tqchildren (if
+ * Iterator class for children of a @ref KFileInfo object. This iterator
+ * returns children sorted by name: Subdirectories first, then the dot
+ * entry (if desired - depending on policy), then file children (if
* desired). Note: If you don't need the sorting feature, you might want to
* use @ref KFileItemIterator instead which has better performance.
@@ -187,13 +187,13 @@ namespace KDirStat
* use @ref KFileItemIterator instead which has better performance.
*
- * @short sorted iterator for @ref KFileInfo tqchildren.
+ * @short sorted iterator for @ref KFileInfo children.
**/
class KFileInfoSortedIterator: public KFileInfoIterator
@@ -248,15 +248,15 @@ namespace KDirStat
void delayedInit();
/**
- * Make a 'default order' tqchildren list:
+ * Make a 'default order' children list:
* First all subdirectories sorted by name,
* then the dot entry (depending on policy),
@@ -248,15 +248,15 @@ namespace KDirStat
* First all subdirectories sorted by name,
* then the dot entry (depending on policy),
- * then the dot entry's tqchildren (depending on policy).
+ * then the dot entry's children (depending on policy).
**/
virtual void makeDefaultOrderChildrenList();
@@ -248,15 +248,15 @@ namespace KDirStat
virtual void makeDefaultOrderChildrenList();
/**
- * Make a sorted tqchildren list according to the current sort
+ * Make a sorted children list according to the current sort
* criteria - unless KSortByName is requested, in which case
* makeDefaultOrderChildrenList() above is used.
@@ -276,8 +276,8 @@ namespace KDirStat
/**
* Specialized KFileInfo iterator that sorts by (total) size, yet
- * disregards tqchildren below a minimum size. This can considerably improve
- * performance if the number of tqchildren that need to be sorted decreases
+ * disregards children below a minimum size. This can considerably improve
+ * performance if the number of children that need to be sorted decreases
* dramatically.
*
@@ -307,7 +307,7 @@ namespace KDirStat
protected:
/**
- * Create the (sorted) tqchildren list. Disregard tqchildren below minSize.
+ * Create the (sorted) children list. Disregard children below minSize.
* Reimplemented from KFileInfoSortedIterator.
**/
diff --git a/kdirstat/ktreemaptile.cpp b/kdirstat/ktreemaptile.cpp
index 5826eb0..6efed77 100644
--- a/kdirstat/ktreemaptile.cpp
+++ b/kdirstat/ktreemaptile.cpp
@@ -79,7 +79,7 @@ KTreemapTile::init()
// Set up height (z coordinate) - one level higher than the parent so this
// will be closer to the foreground.
//
// Note that this must happen before any tqchildren are created.
// I found that out the hard way. ;-)
setZ( _parentTile ? ( _parentTile->z() + 1.0 ) : 0.0 );
@@ -184,12 +184,12 @@ KTreemapTile::createSquarifiedChildren( const TQRect & rect )
#endif
KFileInfoSortedBySizeIterator it( _orig, minSize, KDotEntryAsSubDir );
- TQRect tqchildrenRect = rect;
+ TQRect childrenRect = rect;
while ( *it )
{
- KFileInfoList row = squarify( tqchildrenRect, scale, it );
- tqchildrenRect = layoutRow( tqchildrenRect, scale, row );
+ KFileInfoList row = squarify( childrenRect, scale, it );
+ childrenRect = layoutRow( childrenRect, scale, row );
}
}
@@ -287,7 +287,7 @@ KTreemapTile::layoutRow( const TQRect & rect,
return rect;
- // Set up a cushion surface for this tqlayout row:
+ // Set up a cushion surface for this layout row:
// Add another ridge perpendicular to the row's direction
// that optically groups this row's tiles together.
@@ -79,7 +79,7 @@ KTreemapTile::init()
// will be closer to the foreground.
//
- // Note that this must happen before any tqchildren are created.
+ // Note that this must happen before any children are created.
// I found that out the hard way. ;-)
setZ( _parentTile ? ( _parentTile->z() + 1.0 ) : 0.0 );